from dbt.adapters.sqlserver import SQLServerAdapter

from dbt.adapters.synapse.synapse_connection_manager import SynapseConnectionManager


class SynapseAdapter(SQLServerAdapter):
    ConnectionManager = SynapseConnectionManager



from dataclasses import dataclass

from dbt.adapters.sqlserver import SQLServerCredentials


@dataclass
class SynapseCredentials(SQLServerCredentials):
    @property
    def type(self):
        return "synapse"
